@@ -1,6 +1,6 @@
+from bridger.buttons import WidgetButton
 from bridger import serializers
 
-
 from .models import Notification
 
 
@@ -8,7 +8,15 @@ class NotificationModelSerializer(serializers.ModelSerializer):
 
     @serializers.register_dynamic_button()
     def notification_buttons(self, instance, request, user):
-        return instance.buttons
+        btns = instance.buttons or []
+        if instance.endpoint:
+            btns.append(WidgetButton(
+                endpoint=instance.endpoint,
+                label="Open",
+                title="Open",
+                icon="wb-icon-data"
+            ))
+        return btns
 
     class Meta:
         model = Notification
