@@ -4,9 +4,10 @@ from django.views.generic import TemplateView
 from .frontend_user_configuration import FrontendUserConfigurationModelViewSet
 from .notifications.viewsets import NotificationModelViewSet
 from .routers import BridgerRouter
-from .views import Config, Menu, Profile
+from .views import Config, Profile
 
 from .share.views import ShareAPIView
+from .menus.views import MenuAPIView
 
 # fmt: off
 router = BridgerRouter()
@@ -17,7 +18,7 @@ router.register(r"notification", NotificationModelViewSet, basename="notificatio
 urlpatterns = [
     path("config/", Config.as_view(), name="config"),
     path("profile/", Profile.as_view(), name="profile"),
-    path("menu/", Menu.as_view(), name="menu"),
+    path("menu/", MenuAPIView.as_view(), name="menu"),
     path("share/", ShareAPIView.as_view(), name="share"),
     path("", include(router.urls)),
 ]
